# Help

`awscreds -h`

# Store credentials

`awscreds add`

# Delete credentials

`awscreds delete`

# Get credentials

`awscreds get -e prj_name`

# Export credentials into your session

```
eval `awscreds get -e prj_name`
```
